@@ -12,6 +12,7 @@
 # Project:coN900
 # Author:humble
 
+
 import pygtk
 pygtk.require('2.0')
 import gtk
@@ -32,6 +33,7 @@ class GUI:
         
         if response == gtk.RESPONSE_YES :
            window = hildon.StackableWindow()
+	   #window = gtk.Window()
            window.set_title("Editor")
            window.set_border_width(1)
            window.set_default_size(200, 200)
@@ -90,8 +92,6 @@ class GUI:
         os.system("top -b -n 1 > /home/findump.txt")
         
         window = gtk.Window()
-        #stack = hildon.WindowStack()
-        #stack.push_1(window)
         
         window.set_title("Found Process")
         window.set_border_width(1)
@@ -134,10 +134,6 @@ class GUI:
             result = note.system_note_infoprint("Your N900 has been Optimized;)")
 
             print result
-            loop = gobject.MainLoop()
-
-            loop.run()
-            #loop.destroy() 
         
     def View_Script(self, widget):
         window = hildon.StackableWindow()
@@ -173,17 +169,14 @@ class GUI:
         messagedialog.destroy()
         
         if response == gtk.RESPONSE_YES :
-            os.system("sudo cp OptimizeN900 /usr/local/bin/OptimizeN900")
+            os.system("python /opt/CON900/Restore")
             osso_c = osso.Context("osso_test_note", "0.0.1", True)
 
             note = osso.SystemNote(osso_c)
 
-            result = note.system_note_infoprint("Your N900 has been Restored:)")
+            result = note.system_note_infoprint("Your OptimizeN900 Script has been Restored:)")
 
             print result
-            loop = gobject.MainLoop()
-
-            loop.run()
              
         elif response == gtk.RESPONSE_NO :
             pass
@@ -191,7 +184,7 @@ class GUI:
     def about_page(self, widget):
         aboutdialog = gtk.AboutDialog()        
         aboutdialog.set_name("CON900")
-        aboutdialog.set_version("0.0.9")
+        aboutdialog.set_version("0.0.9-1")
         aboutdialog.set_comments("This application was created to ease the customization of OptimizeN900 Script. It's coded in PyGTK.")
         aboutdialog.set_license("GNU LGPL 2.1")
         aboutdialog.set_website("humblecon900.garage.maemo.org")
@@ -211,25 +204,13 @@ class GUI:
     def __init__(self):
     
         self.window = hildon.StackableWindow()
-        gtk.set_application_name("CON900")
+	#self.window = gtk.Window()
         self.window.set_title("CON900")
 
         self.window.connect("delete_event", self.delete_event)
 
         self.window.set_border_width(10)
         self.window.set_default_size(800, 480)
-       
-#-i removed it here and made it a button soon i want to put it in the title... 
-        #aboutdialog = gtk.AboutDialog()        
-        #aboutdialog.set_name("CON900")
-        #aboutdialog.set_version("0.0.8-8")
-        #aboutdialog.set_comments("This application was created to ease the customization of OptimizeN900 Script. It's coded in PyGTK.")
-        #aboutdialog.set_license("GNU LGPL 2.1")
-        #aboutdialog.set_website("humblecon900.garage.maemo.org")
-        #aboutdialog.set_authors(["humble"])
-
-        #aboutdialog.run()
-        #aboutdialog.destroy()
         
         hbox = gtk.HBox(True, 10)
         vbox_left = gtk.VBox(True, 10)
@@ -242,44 +223,33 @@ class GUI:
 
         label = gtk.Label("OptimizeN900\nEditor")
         label.modify_font(pango.FontDescription("tahoma 24"))
-        #label.props.angle = 40
         label.set_line_wrap(True)
         vbox_left.pack_start(label)
         
         button1 =gtk.Button("TEST")
-        button1.connect("clicked", self.Test_Script)
+        button1.connect("pressed", self.Test_Script)
         vbox_left.pack_start(button1)
 
         button2 = gtk.Button("Find")
-        button2.connect("clicked", self.Find_Process)
+        button2.connect("pressed", self.Find_Process)
         vbox_middle.pack_start(button2) 
 
 	button3 = gtk.Button("View")
-        button3.connect("clicked", self.View_Script)
-        vbox_right.pack_start(button3)
-        
-# Broke do to major change in packaging.. In future update will fix but need solution. 
+        button3.connect("pressed", self.View_Script)
+        vbox_right.pack_start(button3) 
 
 	button4 = gtk.Button("Restore")
-        button4.connect("clicked", self.about_page)
-        button4.set_sensitive(False)
+        button4.connect("pressed", self.Restore_script)
         vbox_right.pack_start(button4)
 
         button5 = gtk.Button("About")
-        button5.connect("clicked", self.about_page)
+        button5.connect("pressed", self.about_page)
         vbox_right.pack_start(button5)
                 
         button6 = gtk.Button("Edit")
-        button6.connect("clicked", self.Edit_Script)
+        button6.connect("pressed", self.Edit_Script)
         vbox_middle.pack_end(button6)
 
-        # Removed. It stop working.
-    
-	#button7 = gtk.Button("Quit") 
-        #button7.connect("clicked", lambda w: gtk.main_quit())
-        #button7.connect("clicked", self.destroy(self))
-        
-        #vbox_left.pack_end(button4)
         self.window.add(hbox)
         self.window.show_all()
 
